summaryrefslogtreecommitdiffstats
path: root/konqueror/sidebar/trees
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:43:14 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:43:14 -0600
commit79b21d47bce1ee428affc97534cd8b257232a871 (patch)
tree0df1fa0109d9f2bcef932eda8b5c25b2e06669ed /konqueror/sidebar/trees
parent9a898d493f493adbc404f7223043c85f3817472b (diff)
downloadtdebase-79b21d47bce1ee428affc97534cd8b257232a871.tar.gz
tdebase-79b21d47bce1ee428affc97534cd8b257232a871.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'konqueror/sidebar/trees')
-rw-r--r--konqueror/sidebar/trees/dirtree_module/dirtree_item.cpp4
-rw-r--r--konqueror/sidebar/trees/dirtree_module/dirtree_module.cpp8
-rw-r--r--konqueror/sidebar/trees/history_module/history_item.cpp2
-rw-r--r--konqueror/sidebar/trees/history_module/history_module.cpp8
-rw-r--r--konqueror/sidebar/trees/history_module/history_module.h2
-rw-r--r--konqueror/sidebar/trees/history_module/history_settings.cpp2
-rw-r--r--konqueror/sidebar/trees/history_module/kcmhistory.cpp2
-rw-r--r--konqueror/sidebar/trees/konq_sidebartree.cpp18
-rw-r--r--konqueror/sidebar/trees/konqsidebar_tree.cpp2
9 files changed, 24 insertions, 24 deletions
diff --git a/konqueror/sidebar/trees/dirtree_module/dirtree_item.cpp b/konqueror/sidebar/trees/dirtree_module/dirtree_item.cpp
index 811867b14..16520d0e0 100644
--- a/konqueror/sidebar/trees/dirtree_module/dirtree_item.cpp
+++ b/konqueror/sidebar/trees/dirtree_module/dirtree_item.cpp
@@ -92,7 +92,7 @@ void KonqSidebarDirTreeItem::setOpen( bool open )
MYMODULE->openSubFolder( this );
else if ( hasStandardIcon() )
{
- int size = KGlobal::iconLoader()->currentSize( KIcon::Small );
+ int size = TDEGlobal::iconLoader()->currentSize( KIcon::Small );
if ( open )
setPixmap( 0, DesktopIcon( "folder_open", size ) );
else
@@ -159,7 +159,7 @@ void KonqSidebarDirTreeItem::itemSelected()
{
bool bInTrash = false;
- if ( m_fileItem->url().directory(false) == KGlobalSettings::trashPath() )
+ if ( m_fileItem->url().directory(false) == TDEGlobalSettings::trashPath() )
bInTrash = true;
TQMimeSource *data = TQApplication::clipboard()->data();
diff --git a/konqueror/sidebar/trees/dirtree_module/dirtree_module.cpp b/konqueror/sidebar/trees/dirtree_module/dirtree_module.cpp
index c8707970c..7d8f7b1fd 100644
--- a/konqueror/sidebar/trees/dirtree_module/dirtree_module.cpp
+++ b/konqueror/sidebar/trees/dirtree_module/dirtree_module.cpp
@@ -325,7 +325,7 @@ void KonqSidebarDirTreeModule::openSubFolder( KonqSidebarTreeItem *item )
if ( !item->isTopLevelItem() &&
static_cast<KonqSidebarDirTreeItem *>(item)->hasStandardIcon() )
{
- int size = KGlobal::iconLoader()->currentSize( KIcon::Small );
+ int size = TDEGlobal::iconLoader()->currentSize( KIcon::Small );
TQPixmap pix = DesktopIcon( "folder_open", size );
m_pTree->startAnimation( item, "kde", 6, &pix );
}
@@ -358,7 +358,7 @@ void KonqSidebarDirTreeModule::listDirectory( KonqSidebarTreeItem *item )
{
// We have this directory listed already, just copy the entries as we
// can't use the dirlister, it would invalidate the old entries
- int size = KGlobal::iconLoader()->currentSize( KIcon::Small );
+ int size = TDEGlobal::iconLoader()->currentSize( KIcon::Small );
KonqSidebarTreeItem * parentItem = item;
KonqSidebarDirTreeItem *oldItem = static_cast<KonqSidebarDirTreeItem *> (openItem->firstChild());
while(oldItem)
@@ -424,7 +424,7 @@ void KonqSidebarDirTreeModule::slotNewItems( const KFileItemList& entries )
}
kdDebug()<<"number of additional parent items:"<< (parentItemList?parentItemList->count():0)<<endl;
- int size = KGlobal::iconLoader()->currentSize( KIcon::Small );
+ int size = TDEGlobal::iconLoader()->currentSize( KIcon::Small );
do
{
kdDebug()<<"Parent Item URL:"<<parentItem->externalURL()<<endl;
@@ -456,7 +456,7 @@ void KonqSidebarDirTreeModule::slotNewItems( const KFileItemList& entries )
void KonqSidebarDirTreeModule::slotRefreshItems( const KFileItemList &entries )
{
- int size = KGlobal::iconLoader()->currentSize( KIcon::Small );
+ int size = TDEGlobal::iconLoader()->currentSize( KIcon::Small );
TQPtrListIterator<KFileItem> kit ( entries );
kdDebug(1201) << "KonqSidebarDirTreeModule::slotRefreshItems " << entries.count() << " entries. First: " << kit.current()->url().url() << endl;
diff --git a/konqueror/sidebar/trees/history_module/history_item.cpp b/konqueror/sidebar/trees/history_module/history_item.cpp
index 0d31551f9..44389702e 100644
--- a/konqueror/sidebar/trees/history_module/history_item.cpp
+++ b/konqueror/sidebar/trees/history_module/history_item.cpp
@@ -119,7 +119,7 @@ TQString KonqSidebarHistoryItem::toolTipText() const
// .arg() calls. So to fix this, we first substitute the last items
// and then put in the url.
TQString tip = i18n("<qt><center><b>%4</b></center><hr>Last visited: %1<br>First visited: %2<br>Number of times visited: %3</qt>");
- return tip.arg( KGlobal::locale()->formatDateTime( m_entry->lastVisited ) ).arg( KGlobal::locale()->formatDateTime( m_entry->firstVisited ) ).arg( m_entry->numberOfTimesVisited ).arg( m_entry->url.url() );
+ return tip.arg( TDEGlobal::locale()->formatDateTime( m_entry->lastVisited ) ).arg( TDEGlobal::locale()->formatDateTime( m_entry->firstVisited ) ).arg( m_entry->numberOfTimesVisited ).arg( m_entry->url.url() );
}
return m_entry->url.url();
diff --git a/konqueror/sidebar/trees/history_module/history_module.cpp b/konqueror/sidebar/trees/history_module/history_module.cpp
index a7fd943ca..71c1b5a44 100644
--- a/konqueror/sidebar/trees/history_module/history_module.cpp
+++ b/konqueror/sidebar/trees/history_module/history_module.cpp
@@ -56,7 +56,7 @@ KonqSidebarHistoryModule::KonqSidebarHistoryModule( KonqSidebarTree * parentTree
m_dict.setAutoDelete( true );
m_currentTime = TQDateTime::currentDateTime();
- KConfig *kc = KGlobal::config();
+ KConfig *kc = TDEGlobal::config();
KConfigGroupSaver cs( kc, "HistorySettings" );
m_sortsByName = kc->readEntry( "SortHistory", "byDate" ) == "byName";
@@ -111,7 +111,7 @@ KonqSidebarHistoryModule::~KonqSidebarHistoryModule()
++it;
}
- KConfig *kc = KGlobal::config();
+ KConfig *kc = TDEGlobal::config();
KConfigGroupSaver cs( kc, "HistorySettings" );
kc->writeEntry("OpenGroups", openGroups);
kc->sync();
@@ -143,7 +143,7 @@ void KonqSidebarHistoryModule::slotCreateItems()
++it;
}
- KConfig *kc = KGlobal::config();
+ KConfig *kc = TDEGlobal::config();
KConfigGroupSaver cs( kc, "HistorySettings" );
TQStringList openGroups = kc->readListEntry("OpenGroups");
TQStringList::Iterator it2 = openGroups.begin();
@@ -297,7 +297,7 @@ void KonqSidebarHistoryModule::sortingChanged()
{
m_topLevelItem->sort();
- KConfig *kc = KGlobal::config();
+ KConfig *kc = TDEGlobal::config();
KConfigGroupSaver cs( kc, "HistorySettings" );
kc->writeEntry( "SortHistory", m_sortsByName ? "byName" : "byDate" );
kc->sync();
diff --git a/konqueror/sidebar/trees/history_module/history_module.h b/konqueror/sidebar/trees/history_module/history_module.h
index 752ff57fd..cbba40262 100644
--- a/konqueror/sidebar/trees/history_module/history_module.h
+++ b/konqueror/sidebar/trees/history_module/history_module.h
@@ -61,7 +61,7 @@ public:
bool sortsByName() const { return m_sortsByName; }
static TQString groupForURL( const KURL& url ) {
- static const TQString& misc = KGlobal::staticQString(i18n("Miscellaneous"));
+ static const TQString& misc = TDEGlobal::staticQString(i18n("Miscellaneous"));
return url.host().isEmpty() ? misc : url.host();
}
diff --git a/konqueror/sidebar/trees/history_module/history_settings.cpp b/konqueror/sidebar/trees/history_module/history_settings.cpp
index 6871415a0..3e8c8a5de 100644
--- a/konqueror/sidebar/trees/history_module/history_settings.cpp
+++ b/konqueror/sidebar/trees/history_module/history_settings.cpp
@@ -46,7 +46,7 @@ void KonqSidebarHistorySettings::readSettings(bool global)
TQString oldgroup;
if (global) {
- config = KGlobal::config();
+ config = TDEGlobal::config();
oldgroup= config->group();
}
else
diff --git a/konqueror/sidebar/trees/history_module/kcmhistory.cpp b/konqueror/sidebar/trees/history_module/kcmhistory.cpp
index 532e3a164..a1ef792d6 100644
--- a/konqueror/sidebar/trees/history_module/kcmhistory.cpp
+++ b/konqueror/sidebar/trees/history_module/kcmhistory.cpp
@@ -51,7 +51,7 @@ K_EXPORT_COMPONENT_FACTORY (kcm_history, KCMHistoryFactory("kcmhistory") )
HistorySidebarConfig::HistorySidebarConfig( TQWidget *parent, const char* name, const TQStringList & )
: KCModule (KCMHistoryFactory::instance(), parent, name)
{
- KGlobal::locale()->insertCatalogue("konqueror");
+ TDEGlobal::locale()->insertCatalogue("konqueror");
m_settings = new KonqSidebarHistorySettings( 0, "history settings" );
m_settings->readSettings( false );
diff --git a/konqueror/sidebar/trees/konqsidebar_tree.cpp b/konqueror/sidebar/trees/konqsidebar_tree.cpp
index 0dc9303b4..1cdf54da0 100644
--- a/konqueror/sidebar/trees/konqsidebar_tree.cpp
+++ b/konqueror/sidebar/trees/konqsidebar_tree.cpp
@@ -134,7 +134,7 @@ extern "C"
{
KDE_EXPORT bool add_konqsidebar_tree(TQString* fn, TQString*, TQMap<TQString,TQString> *map)
{
- KStandardDirs *dirs=KGlobal::dirs();
+ KStandardDirs *dirs=TDEGlobal::dirs();
TQStringList list=dirs->findAllResources("data","konqsidebartng/dirtree/*.desktop",false,true);
TQStringList names;
for (TQStringList::ConstIterator it=list.begin();it!=list.end();++it)
diff --git a/konqueror/sidebar/trees/konq_sidebartree.cpp b/konqueror/sidebar/trees/konq_sidebartree.cpp
index 2ed02b6cf..7ba7c3014 100644
--- a/konqueror/sidebar/trees/konq_sidebartree.cpp
+++ b/konqueror/sidebar/trees/konq_sidebartree.cpp
@@ -87,7 +87,7 @@ void KonqSidebarTree::loadModuleFactories()
{
pluginFactories.clear();
pluginInfo.clear();
- KStandardDirs *dirs=KGlobal::dirs();
+ KStandardDirs *dirs=TDEGlobal::dirs();
TQStringList list=dirs->findAllResources("data","konqsidebartng/dirtree/*.desktop",false,true);
@@ -168,12 +168,12 @@ KonqSidebarTree::KonqSidebarTree( KonqSidebar_Tree *parent, TQWidget *parentWidg
/* assert( m_part->getInterfaces()->getInstance()->dirs );
TQString dirtreeDir = m_part->getInterfaces()->getInstance()->dirs()->saveLocation( "data", "konqueror/dirtree/" ); */
-// assert( KGlobal::dirs() );
+// assert( TDEGlobal::dirs() );
// TQString dirtreeDir = part->getInterfaces()->getInstance()->dirs()->saveLocation( "data", "konqueror/dirtree/" );
if (virt==VIRT_Folder)
{
- m_dirtreeDir.dir.setPath(KGlobal::dirs()->saveLocation("data","konqsidebartng/virtual_folders/"+path+"/"));
+ m_dirtreeDir.dir.setPath(TDEGlobal::dirs()->saveLocation("data","konqsidebartng/virtual_folders/"+path+"/"));
m_dirtreeDir.relDir=path;
}
else
@@ -620,10 +620,10 @@ void KonqSidebarTree::scanDir( KonqSidebarTreeItem *parent, const TQString &path
if (copyConfig)
{
// We will copy over the configuration for the dirtree, from the global directory
- TQStringList dirtree_dirs = KGlobal::dirs()->findDirs("data","konqsidebartng/virtual_folders/"+m_dirtreeDir.relDir+"/");
+ TQStringList dirtree_dirs = TDEGlobal::dirs()->findDirs("data","konqsidebartng/virtual_folders/"+m_dirtreeDir.relDir+"/");
-// TQString dirtree_dir = KGlobal::dirs()->findDirs("data","konqsidebartng/virtual_folders/"+m_dirtreeDir.relDir+"/").last(); // most global
+// TQString dirtree_dir = TDEGlobal::dirs()->findDirs("data","konqsidebartng/virtual_folders/"+m_dirtreeDir.relDir+"/").last(); // most global
// kdDebug(1201) << "KonqSidebarTree::scanDir dirtree_dir=" << dirtree_dir << endl;
/*
@@ -655,9 +655,9 @@ void KonqSidebarTree::scanDir( KonqSidebarTreeItem *parent, const TQString &path
&& !entries.contains( *eIt ) && !dirEntries.contains( *eIt ) )
{ // we don't have that one yet -> copy it.
TQString cp("cp -R -- ");
- cp += KProcess::quote(dirtree_dir + *eIt);
+ cp += TDEProcess::quote(dirtree_dir + *eIt);
cp += " ";
- cp += KProcess::quote(path);
+ cp += TDEProcess::quote(path);
kdDebug(1201) << "KonqSidebarTree::scanDir executing " << cp << endl;
::system( TQFile::encodeName(cp) );
}
@@ -698,7 +698,7 @@ void KonqSidebarTree::scanDir( KonqSidebarTreeItem *parent, const TQString &path
{
TQString newPath = TQString( path ).append( *eIt ).append( '/' );
- if ( newPath == KGlobalSettings::autostartPath() )
+ if ( newPath == TDEGlobalSettings::autostartPath() )
continue;
loadTopLevelGroup( parent, newPath );
@@ -984,7 +984,7 @@ void KonqSidebarTree::slotCreateFolder()
name = name + "-2";
}
- KGlobal::dirs()->makeDir(path);
+ TDEGlobal::dirs()->makeDir(path);
loadTopLevelGroup(m_currentTopLevelItem, path);
}